# LiPF6 electrolyte parameters

Parameters for a LiPF6 electrolyte, from the paper

> A. Nyman, M. Behm, and G. Lindbergh, ["Electrochemical characterisation and modelling of the mass transport phenomena in LiPF6-EC-EMC electrolyte,"](https://www.sciencedirect.com/science/article/pii/S0013468608005045) Electrochim. Acta, vol. 53, no. 22, pp. 6356–6365, 2008.

and references therein.
